@@ -1,9 +1,9 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "stgit" "2.5.5"
+(define-package "stgit" "20251110.503"
   "Major mode for StGit interaction."
   ()
   :url "http://stacked-git.github.io"
   :commit "020140581698f62d846c995ee6e3bebe0c20ff14"
-  :revdesc "v2.5.5-0-g020140581698"
+  :revdesc "020140581698"
   :authors '(("David Kågedal" . "davidk@lysator.liu.se"))
   :maintainers '(("David Kågedal" . "davidk@lysator.liu.se")))
